@@ -19,7 +19,7 @@ with 'Data::Object::Role::Stashable';
 
 use DBI;
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 # ATTRIBUTES
 
@@ -86,6 +86,16 @@ fun new_odbcdsn($self) {
   $ENV{TESTDB_ODBCDSN}
 }
 
+has 'uri' => (
+  is => 'ro',
+  isa => 'Str',
+  new => 1,
+);
+
+fun new_uri($self) {
+  $self->urigen($self->database)
+}
+
 has 'username' => (
   is => 'ro',
   isa => 'Str',
@@ -126,6 +136,7 @@ method clone(Str $source = $self->template) {
   $dbh->disconnect;
 
   $self->dbh;
+  $self->uri;
   $self->immutable;
 
   return $self;
@@ -182,6 +193,14 @@ method dsngen(Str $name) {
     ($self->hostport ? ("port=@{[$self->hostport]}") : ())
 }
 
+method urigen(Str $name) {
+  join('/', 'mssql', ($self->username ? '' : ()), ($self->username ?
+    join('@', join(':', $self->username ? ($self->username, ($self->password ? $self->password : ())) : ()),
+    $self->hostname ? ($self->hostport ? (join(':', $self->hostname, $self->hostport)) : $self->hostname) : '') : ()),
+    $name
+  )
+}
+
 1;
 
 =encoding utf8
@@ -302,6 +321,14 @@ This attribute is read-only, accepts C<(Str)> values, and is optional.
 
 =cut
 
+=head2 uri
+
+  uri(Str)
+
+This attribute is read-only, accepts C<(Str)> values, and is optional.
+
+=cut
+
 =head2 username
 
   username(Str)
