@@ -19,7 +19,7 @@ with 'Data::Object::Role::Stashable';
 
 use DBI;
 
-our $VERSION = '0.06'; # VERSION
+our $VERSION = '0.07'; # VERSION
 
 # ATTRIBUTES
 
@@ -76,6 +76,16 @@ fun new_initial($self) {
   $ENV{TESTDB_INITIAL} || 'mysql'
 }
 
+has 'uri' => (
+  is => 'ro',
+  isa => 'Str',
+  new => 1,
+);
+
+fun new_uri($self) {
+  $self->urigen($self->database)
+}
+
 has 'username' => (
   is => 'ro',
   isa => 'Str',
@@ -116,6 +126,7 @@ method create() {
   $dbh->disconnect;
 
   $self->dbh;
+  $self->uri;
   $self->immutable;
 
   return $self;
@@ -149,6 +160,14 @@ method dsngen(Str $name) {
     ($self->hostport ? ("port=@{[$self->hostport]}") : ())
 }
 
+method urigen(Str $name) {
+  join('/', 'mysql', ($self->username ? '' : ()), ($self->username ?
+    join('@', join(':', $self->username ? ($self->username, ($self->password ? $self->password : ())) : ()),
+    $self->hostname ? ($self->hostport ? (join(':', $self->hostname, $self->hostport)) : $self->hostname) : '') : ()),
+    $name
+  )
+}
+
 1;
 
 =encoding utf8
@@ -268,6 +287,14 @@ This attribute is read-only, accepts C<(Str)> values, and is optional.
 
 =cut
 
+=head2 uri
+
+  uri(Str)
+
+This attribute is read-only, accepts C<(Str)> values, and is optional.
+
+=cut
+
 =head2 username
 
   username(Str)
